@@ -19,6 +19,7 @@
 #include <e-util/e-icon-factory.h>
 #include <e-util/e-popup.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <glib/gi18n.h>
 
 #include "sunone-config-listener.h"
 #include "sunone-permissions-dialog.h"
@@ -63,7 +64,7 @@ static void
 destroy_page (gpointer key, gpointer value, gpointer user_data)
 {
 	g_free (key);
-	gtk_widget_unref (GTK_WIDGET (value));
+	g_object_unref (GTK_WIDGET (value));
 }
 
 static void
@@ -131,7 +132,7 @@ sunone_folder_tree_view_new (SunOneFolderTree *tree, const char *physical_uri)
 
 	widget = sunone_invitation_list_new (model);
 	gtk_widget_show (widget);
-	gtk_widget_ref (widget);
+	g_object_ref (widget);
 
 	return widget;
 }
@@ -145,7 +146,7 @@ sunone_folder_tree_no_view ()
 		label = gtk_label_new (_("Cannot display this folder in this view.\n Please switch to Calendars/Tasks view to see the calendars/tasks.\n\n This view is used to create or delete calendar/tasks folders,\n manage folder permissions and subscriptions, show your invitations."));
 		gtk_label_set_justify ((GtkLabel *)label, GTK_JUSTIFY_CENTER);
 	}
-	gtk_widget_ref (label);
+	g_object_ref (label);
 
 	return label;
 }
@@ -255,7 +256,7 @@ add_folder_tree_item (SunOneFolderTree *tree, SunOneAccount *account, GtkTreeIte
 	g_return_if_fail (account != NULL);
 
 	/* create the invitation list model now */
-	physical_uri = sunone_util_get_physical_uri_from_account (account, calid, "invitations");
+	physical_uri = sunone_account_get_physical_uri (account, calid, "invitations");
 	g_static_mutex_lock (&mutex);
 	model = SUNONE_INVITATION_LIST_MODEL (sunone_invitation_list_model_new (physical_uri));
 	g_static_mutex_unlock (&mutex);
@@ -264,7 +265,7 @@ add_folder_tree_item (SunOneFolderTree *tree, SunOneAccount *account, GtkTreeIte
 	priv->invitation_models = g_list_prepend (priv->invitation_models, model);
 
 	full_name = g_strdup_printf ("/%s/%s/", sunone_account_get_name (account), calid);
-	physical_uri = sunone_util_get_physical_uri_from_account (account, calid, "folder");
+	physical_uri = sunone_account_get_physical_uri (account, calid, "folder");
 	gtk_tree_store_append (priv->treeview_model, &iter1, iter);
 	gtk_tree_store_set (priv->treeview_model, &iter1,
 				COL_STRING_DISPLAY_NAME, display_name,
@@ -281,7 +282,7 @@ add_folder_tree_item (SunOneFolderTree *tree, SunOneAccount *account, GtkTreeIte
 	g_free (full_name);
 
 	full_name = g_strdup_printf ("/%s/%s/invitations", sunone_account_get_name (account), calid);
-	physical_uri = sunone_util_get_physical_uri_from_account (account, calid, "invitations");
+	physical_uri = sunone_account_get_physical_uri (account, calid, "invitations");
 	gtk_tree_store_append (priv->treeview_model, &iter2, &iter1);
 	gtk_tree_store_set (priv->treeview_model, &iter2,
 				COL_STRING_DISPLAY_NAME, "Invitations",
@@ -332,13 +333,18 @@ sunone_folder_tree_connect (SunOneFolderTree *tree, SunOneAccount *account,
 
 	g_return_if_fail (SUNONE_IS_FOLDER_TREE (tree));
 
+	sunone_account_set_connecting (account, TRUE);
 	cnc = sunone_account_get_connection (account);
-	if (!cnc)
+	if (!cnc) {
+		sunone_account_set_connecting (account, FALSE);
 		return;
+	}
 
 	prefs = sunone_connection_get_preferences (cnc);
-	if (!prefs)
+	if (!prefs) {
+		sunone_account_set_connecting (account, FALSE);
 		return;
+	}
 
 	/* add tree items to sunone folder tree */
 	add_folder_tree (tree, account, iter, prefs);
@@ -346,6 +352,7 @@ sunone_folder_tree_connect (SunOneFolderTree *tree, SunOneAccount *account,
 	add_sources (account, prefs);
 	
 	sunone_connection_free_preferences (prefs);
+	sunone_account_set_connecting (account, FALSE);
 }
 
 static void
@@ -360,6 +367,8 @@ remove_calendar (SunOneFolderTree *tree, const char *full_name)
 
 	g_return_if_fail (SUNONE_IS_FOLDER_TREE (tree));
 
+	if (!full_hash)
+		return;
 	uri_row = g_hash_table_lookup (full_hash, full_name);
 	if (!uri_row)
 		return;
@@ -398,7 +407,6 @@ create_folder_tree_with_thread (TreeCreateData *data)
 	GtkTreeIter iter = data->iter;
 	GtkTreeIter sub_iter;
 	GtkTreePath *path;
-	int mode;
 
 	gtk_tree_store_append (priv->treeview_model, &sub_iter, &iter);
 	gtk_tree_store_set (priv->treeview_model, &sub_iter,
@@ -444,7 +452,7 @@ sunone_folder_tree_created (SunOneFolderTree *tree, SunOneAccount *account)
 	full_name = g_strdup_printf ("/%s/", sunone_account_get_name (account));
 	remove_calendar (tree, full_name);
 
-	physical_uri = sunone_util_get_physical_uri_from_account (account, sunone_account_get_user (account), "folder");
+	physical_uri = sunone_account_get_physical_uri (account, sunone_account_get_user (account), "folder");
 	gtk_tree_store_append (priv->treeview_model, &iter, NULL);
 	gtk_tree_store_set (priv->treeview_model, &iter,
 				COL_STRING_DISPLAY_NAME, sunone_account_get_name (account),
@@ -482,10 +490,6 @@ void
 sunone_folder_tree_removed (SunOneFolderTree *tree, SunOneAccount *account)
 {
 	SunOneFolderTreePrivate *priv = tree->priv;
-	SunOneCalendarSubscription *sub;
-	SunOneConnectionPreferences *prefs;
-	SunOneConnection *cnc;
-	GList *l;
 	char *full_name;
 	GtkWidget *page;
 	int page_num;
@@ -632,7 +636,7 @@ render_display_name (GtkTreeViewColumn *column, GtkCellRenderer *renderer,
 
 	display = name;
 
-	if (!strcmp ("invitations", folder_type)) {
+	if (folder_type && !strcmp ("invitations", folder_type)) {
 		/* check unread count for invitation list */
 		SunOneInvitationListModel *model;
 
